@@ -216,14 +216,59 @@ class AuthenticatedStrategy(Strategy):
         except:
             debug(tag, 'Failed to close chat panel')
 
+    @staticmethod
+    def __extract_apply_link(tag: str, driver: webdriver, cdp: CDP, timeout=4):
+        try:
+            elapsed = 0
+            sleep_time = 0.1
+            current_url = driver.current_url
+
+            debug(tag, 'Evaluating selectors', [Selectors.applyBtn])
+
+            driver.execute_script(
+                r'''
+                    const applyBtn = document.querySelector(arguments[0]);
+
+                    if (applyBtn) {
+                        applyBtn.click();
+                        return true;
+                    }
+
+                    return false;
+                ''',
+                Selectors.applyBtn
+            )
+
+            if len(driver.window_handles) > 1:
+                debug(tag, 'Try extracting apply link')
+
+                while elapsed < timeout:
+                    targets_result = cdp.get_targets()
+
+                    if targets_result['success']:
+                        for target in targets_result['result'].targets:
+                            if target.attached and target.type == 'page' and target.url and \
+                                    target.url != current_url:
+                                cdp.close_target(target.targetId)
+                                return {'success': True, 'apply_link': target.url}
+
+                    sleep(sleep_time)
+                    elapsed += sleep_time
+
+                warn(tag, 'Failed to extract apply link: timeout')
+                return {'success': False, 'error': 'Timeout'}
+            return {'success': False, 'error': 'No handle'}
+        except BaseException as e:
+            warn(tag, 'Failed to extract apply link', e)
+            return {'success': False, 'error': str(e)}
+
     def run(
         self,
         driver: webdriver,
         cdp: CDP,
         search_url: str,
         query: Query,
-        location: str,
-        apply_link: bool
+        location: str
     ) -> None:
         """
         Run strategy
@@ -333,7 +378,7 @@ class AuthenticatedStrategy(Strategy):
                         Selectors.date])
 
                     job_id, job_link, job_title, job_company, job_company_link, \
-                    job_company_img_link, job_place, job_date = \
+                        job_company_img_link, job_place, job_date, job_is_promoted = \
                         driver.execute_script(
                             '''
                                 const index = arguments[0];
@@ -369,6 +414,9 @@ class AuthenticatedStrategy(Strategy):
     
                                 const date = job.querySelector(arguments[6]) ?
                                     job.querySelector(arguments[6]).getAttribute('datetime') : "";
+                                    
+                                const isPromoted = Array.from(job.querySelectorAll('li'))
+                                    .find(e => e.innerText === 'Promoted') ? true : false;
     
                                 return [
                                     jobId,
@@ -379,6 +427,7 @@ class AuthenticatedStrategy(Strategy):
                                     companyImgLink,
                                     place,
                                     date,
+                                    isPromoted,
                                 ];                                                    
                             ''',
                             job_index,
@@ -389,6 +438,24 @@ class AuthenticatedStrategy(Strategy):
                             Selectors.place,
                             Selectors.date)
 
+                    # Promoted jobs
+                    if query.options.skip_promoted_jobs and job_is_promoted:
+                        info(tag, 'Skipped because promoted')
+                        job_index += 1
+                        metrics.skipped += 1
+
+                        # Try fetching more jobs
+                        if metrics.processed < query.options.limit and job_index == job_tot < pagination_size:
+                            load_jobs_result = AuthenticatedStrategy.__load_jobs(driver, job_tot)
+
+                            if load_jobs_result['success']:
+                                job_tot = load_jobs_result['count']
+
+                        if job_index == job_tot:
+                            break
+                        else:
+                            continue
+
                     job_title = normalize_spaces(job_title)
                     job_company = normalize_spaces(job_company)
                     job_place = normalize_spaces(job_place)
@@ -404,7 +471,7 @@ class AuthenticatedStrategy(Strategy):
 
                     if not load_result['success']:
                         error(tag, load_result['error'], exc_info=False)
-                        info(tag, 'Skipped')
+                        info(tag, 'Failed to process')
                         job_index += 1
                         metrics.failed += 1
                         continue
@@ -436,42 +503,11 @@ class AuthenticatedStrategy(Strategy):
                     # Apply link
                     job_apply_link = ''
 
-                    if apply_link:
-                        try:
-                            debug(tag, 'Evaluating selectors', [Selectors.applyBtn])
+                    if query.options.apply_link:
+                        apply_link_result = AuthenticatedStrategy.__extract_apply_link(tag, driver, cdp)
 
-                            driver.execute_script(
-                                r'''
-                                    const applyBtn = document.querySelector(arguments[0]);
-
-                                    if (applyBtn) {
-                                        applyBtn.click();
-                                        return true;
-                                    }
-
-                                    return false;
-                                ''',
-                                Selectors.applyBtn
-                            )
-
-                            if len(driver.window_handles) > 1:
-                                debug(tag, 'Try extracting apply link')
-
-                                targets_result = cdp.get_targets()
-
-                                if targets_result['success']:
-                                    # The first not attached target should be the apply page
-                                    apply_target = next(
-                                        (e for e in targets_result['result'].targets if not e.attached), '')
-
-                                    if apply_target:
-                                        job_apply_link = apply_target.url
-                                        cdp.close_target(apply_target.targetId)
-                                else:
-                                    warn(tag, 'Failed to extract apply link', targets_result['error'])
-
-                        except BaseException as e:
-                            warn(tag, 'Failed to extract apply link', e)
+                        if apply_link_result['success']:
+                            job_apply_link = apply_link_result['apply_link']
 
                     data = EventData(
                         query=query.query,
@@ -517,7 +553,7 @@ class AuthenticatedStrategy(Strategy):
                         error(tag, e, traceback.format_exc())
                         self.scraper.emit(Events.ERROR, str(e) + '\n' + traceback.format_exc())
                     finally:
-                        info(tag, 'Skipped')
+                        info(tag, 'Failed to process')
                         job_index += 1
                         metrics.failed += 1
 
